import { Type } from '@angular/core';
import { IgPoint } from "igniteui-angular-core/ES2015/IgPoint";
import { IgxFinancialOverlayComponent } from "./igx-financial-overlay-component";
import { IgxFinancialSeriesComponent } from "./igx-financial-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { BollingerBandsOverlay } from "./BollingerBandsOverlay";
/**
 * Represents a IgxDataChartComponent Bollinger Bands financial overlay series.
 * Default required members: High, Low, Close
*
* You can use the `IgxBollingerBandsOverlayComponent` class represents a IgxDataChartComponent Bollinger Bands financial overlay series.
*
* ```html
* <igx-data-chart
* 	#chart
*     [dataSource]="data" >
*     <igx-category-x-axis
* 		label="label"
* 		#xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
* 		#yAxis>
*     </igx-numeric-y-axis>
*     <igx-bollinger-band-overlay
* 		[xAxis]="xAxis"
* 		[yAxis]="yAxis"
* 		openMemberPath="open"
* 		highMemberPath="high"
* 		lowMemberPath="low"
* 		closeMemberPath="close">
*     </igx-bollinger-band-overlay>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxBollingerBandOverlayComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
export declare const IgxBollingerBandsOverlayComponent_PROVIDERS: ({
    provide: typeof IgxFinancialSeriesComponent;
    useExisting: Type<any>;
} | {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
})[];
export declare class IgxBollingerBandsOverlayComponent extends IgxFinancialOverlayComponent {
    protected createImplementation(): BollingerBandsOverlay;
    /**
                                 * @hidden
                                 */
    readonly i: BollingerBandsOverlay;
    constructor();
    /**
     * Gets or sets the moving average period for the current BollingerBandOverlay object.
     * The typical, and initial, value for Bollinger band periods is 14.
    *
    * You can use the `period` property for moving average of the current BollingerBandOverlay object.
    *
    * ```html
    * <igx-data-chart
    * 	#chart
    *     [dataSource]="data" >
    *     <igx-category-x-axis
    * 		label="label"
    * 		#xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    * 		#yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-bollinger-band-overlay
    * 		[xAxis]="xAxis"
    * 		[yAxis]="yAxis"
    * 		openMemberPath="open"
    * 		highMemberPath="high"
    * 		lowMemberPath="low"
    * 		closeMemberPath="close"
    * 		period="7">
    *     </igx-bollinger-band-overlay>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.period = 7;
    * ```
    */
    period: number;
    /**
     * Gets or sets the moving average period for the current BollingerBandOverlay object.
     * The typical, and initial, value for Bollinger band multipliers is 2.
    *
    * You can use the `IgxBollingerBandsOverlayComponent`
    */
    multiplier: number;
    getSeriesValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getPreviousOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getNextOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
}
