import * as tslib_1 from "tslib";
var IgxBollingerBandsOverlayComponent_1;
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxFinancialOverlayComponent } from "./igx-financial-overlay-component";
import { IgxFinancialSeriesComponent } from "./igx-financial-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { BollingerBandsOverlay } from "./BollingerBandsOverlay";
import { toPoint } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents a IgxDataChartComponent Bollinger Bands financial overlay series.
 * Default required members: High, Low, Close
*
* You can use the `IgxBollingerBandsOverlayComponent` class represents a IgxDataChartComponent Bollinger Bands financial overlay series.
*
* ```html
* <igx-data-chart
* 	#chart
*     [dataSource]="data" >
*     <igx-category-x-axis
* 		label="label"
* 		#xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
* 		#yAxis>
*     </igx-numeric-y-axis>
*     <igx-bollinger-band-overlay
* 		[xAxis]="xAxis"
* 		[yAxis]="yAxis"
* 		openMemberPath="open"
* 		highMemberPath="high"
* 		lowMemberPath="low"
* 		closeMemberPath="close">
*     </igx-bollinger-band-overlay>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxBollingerBandOverlayComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
export const IgxBollingerBandsOverlayComponent_PROVIDERS = [{ provide: IgxFinancialOverlayComponent, useExisting: forwardRef(() => IgxBollingerBandsOverlayComponent) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(() => IgxBollingerBandsOverlayComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxBollingerBandsOverlayComponent) }];
let IgxBollingerBandsOverlayComponent = IgxBollingerBandsOverlayComponent_1 = class IgxBollingerBandsOverlayComponent extends IgxFinancialOverlayComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new BollingerBandsOverlay();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets the moving average period for the current BollingerBandOverlay object.
     * The typical, and initial, value for Bollinger band periods is 14.
    *
    * You can use the `period` property for moving average of the current BollingerBandOverlay object.
    *
    * ```html
    * <igx-data-chart
    * 	#chart
    *     [dataSource]="data" >
    *     <igx-category-x-axis
    * 		label="label"
    * 		#xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    * 		#yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-bollinger-band-overlay
    * 		[xAxis]="xAxis"
    * 		[yAxis]="yAxis"
    * 		openMemberPath="open"
    * 		highMemberPath="high"
    * 		lowMemberPath="low"
    * 		closeMemberPath="close"
    * 		period="7">
    *     </igx-bollinger-band-overlay>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.period = 7;
    * ```
    */
    get period() {
        return this.i.pt;
    }
    set period(v) {
        this.i.pt = +v;
    }
    /**
     * Gets or sets the moving average period for the current BollingerBandOverlay object.
     * The typical, and initial, value for Bollinger band multipliers is 2.
    *
    * You can use the `IgxBollingerBandsOverlayComponent`
    */
    get multiplier() {
        return this.i.ps;
    }
    set multiplier(v) {
        this.i.ps = +v;
    }
    getSeriesValue(world, useInterpolation, skipUnknowns) {
        let iv = this.i.en(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    }
    getPreviousOrExactIndex(world, skipUnknowns) {
        let iv = this.i.fe(toPoint(world), skipUnknowns);
        return (iv);
    }
    getNextOrExactIndex(world, skipUnknowns) {
        let iv = this.i.fc(toPoint(world), skipUnknowns);
        return (iv);
    }
};
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxBollingerBandsOverlayComponent.prototype, "period", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxBollingerBandsOverlayComponent.prototype, "multiplier", null);
IgxBollingerBandsOverlayComponent = IgxBollingerBandsOverlayComponent_1 = tslib_1.__decorate([
    Component({
        selector: 'igx-bollinger-bands-overlay',
        template: ``,
        providers: [{ provide: IgxFinancialOverlayComponent, useExisting: forwardRef(() => IgxBollingerBandsOverlayComponent_1) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(() => IgxBollingerBandsOverlayComponent_1) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxBollingerBandsOverlayComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    tslib_1.__metadata("design:paramtypes", [])
], IgxBollingerBandsOverlayComponent);
export { IgxBollingerBandsOverlayComponent };
//# sourceMappingURL=igx-bollinger-bands-overlay-component.js.map