import { IgPoint } from "igniteui-angular-core/ES2015/IgPoint";
import { IgxSeriesComponent } from "./igx-series-component";
import { IgxSeriesViewerComponent } from "./igx-series-viewer-component";
import { DataChartMouseButtonEventArgs as DataChartMouseButtonEventArgs_internal } from "./DataChartMouseButtonEventArgs";
/**
 * Provides data for IgxDataChartComponent mouse button related events.
*
* `DataChartMouseButtonEventHandler` class represents the method that will handle IgxDataChartComponent mouse button related events.
*
* ```html
*  <igx-data-chart  #chart
*       [dataSource]="data"
* 	  (seriesMouseLeftButtonDown)="chart_seriesMouseLeftButtonDown()">
*       <igx-category-x-axis
*         label="label"
*         #xAxis
*         >
*       </igx-category-x-axis>
*       <igx-numeric-y-axis
*         minimumValue="0"
*         #yAxis>
*       </igx-numeric-y-axis>
*
*       <igx-column-series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*         valueMemberPath="value">
*       </igx-column-series>
*     </igx-data-chart>
* ```
*
* ```ts
* this.chart.seriesMouseLeftButtonDown.subscribe(this.chart_seriesMouseLeftButtonDown);
* chart_seriesMouseLeftButtonDown(sender :any,args: DataChartMouseButtonEventArgs )
*   {
*   }
* ```
*/
export declare class DataChartMouseButtonEventArgs {
    protected _implementation: any;
    /**
     * @hidden
     */
    readonly i: DataChartMouseButtonEventArgs_internal;
    private onImplementationCreated;
    constructor();
    protected _provideImplementation(i: any): void;
    /**
     * Gets or sets a value that indicates the present state of the event handling for a routed
     * event as it travels the route.
     * ChartMouseButton events are not routed events; setting this property effects the underlying
     * MouseButtonEvent.
    *
    * Use the `handled` property to indicates the present state of the event handling for a routed event.
    */
    handled: boolean;
    /**
     * Gets a reference to the object that raised the event.
    *
    * Use the `originalSource` property for the raised object event.
    *
    * ```ts
    * args.originalSource;
    * ```
    */
    readonly originalSource: any;
    /**
     * Gets the ItemsSource item associated with the current event.
    *
    * Use the `item` property to get the ItemsSource item associated with the current event.
    *
    * ```ts
    * var item1= args.item;
    * ```
    */
    item: any;
    /**
     * Gets the series associated with the current event.
    *
    * Use the `series` property for the associated current event.
    *
    * ```ts
    *  var DataSeries= args.series;
    * ```
    */
    series: IgxSeriesComponent;
    /**
     * Gets the Chart associated with the current event.
    *
    * Use the `chart` property to get the chart associated with the current event.
    *
    * ```ts
    * var dataChart=  args.chart;
    * ```
    */
    chart: IgxSeriesViewerComponent;
    /**
     * Provides a human readable description of the mouse button event.
    
    *
    * Use the `toString` property to provides a human readable discription.
    *
    * ```ts
    *   var item= args.item.label.toString();
    * ```
    */
    toString(): string;
    /**
     * Returns the x- and y- coordinates of the mouse pointer position, optionally evaluated
     * against the origin of a supplied UIElement.
    
    * @param relativeTo  * Any UIElement derived object that is contained by the the engine plug-in
     * and connected to the object tree. To specify the object relative to the overall the engine
     * coordinate system, use a relativeTo value of null.
    *
    * To get mouse X and Y position.
    *
    * ```ts
    *    var args.getPosition;
    * ```
    */
    getPosition(relativeTo: any): IgPoint;
}
