import { Type } from '@angular/core';
import { UnknownValuePlotting } from "igniteui-angular-core/ES5/UnknownValuePlotting";
import { IgxHorizontalAnchoredCategorySeriesComponent } from "./igx-horizontal-anchored-category-series-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { LineSeries } from "./LineSeries";
/**
 * Represents a IgxDataChartComponent line series.
 * Displays trend over time or ordered categories.Useful when there are many data points and the order is important.
*
* `IgxLineSeriesComponent` belongs to a group of `IgxCategorySeriesComponent` and it is rendered using a collection of points connected by straight line segments.
*
* ```html
*  <igx-data-chart
*     [dataSource]="data">
*     <igx-category-x-axis
*         label="label"
*         #xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
*         #yAxis>
*     </igx-numeric-y-axis>
*     <igx-line-series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*         valueMemberPath="value">
*     </igx-line-series>
* </igx-data-chart>
* ```
*
* ```ts
* let series: IgxLineSeriesComponent = new IgxLineSeriesComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.valueMemberPath = "value";
* this.chart.series.add(series);
* ```
*/
export declare const IgxLineSeriesComponent_PROVIDERS: ({
    provide: typeof IgxMarkerSeriesComponent;
    useExisting: Type<any>;
} | {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
})[];
export declare class IgxLineSeriesComponent extends IgxHorizontalAnchoredCategorySeriesComponent {
    protected createImplementation(): LineSeries;
    /**
                                 * @hidden
                                 */
    readonly i: LineSeries;
    constructor();
    /**
     * Gets whether the current series shows an area or line shape.
    *
    * Gets whether the `IgxSeriesComponent` shows an area or a line shape.
    *
    * ```ts
    * let isAreaOrLine: boolean = series.isAreaOrLine;
    * ```
    */
    readonly isAreaOrLine: boolean;
    /**
     * Determines how unknown values will be plotted on the chart.
     * Null and Double.NaN are two examples of unknown values.
    *
    * Determines how unknown values will be plotted for the `IgxSeriesComponent`. This can be set to `LinearInterpolate` to create a continous shape or `DontPlot` to create breaks in the series.
    *
    * Null and Double.NaN are two examples of unknown values.
    *
    * ```html
    * <igx-data-chart #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         unknownValuePlotting="LinearInterpolate">
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * series.unknownValuePlotting = UnknownValuePlotting.LinearInterpolate;
    * ```
    */
    unknownValuePlotting: UnknownValuePlotting;
}
