import { Type } from '@angular/core';
import { IgPoint } from "igniteui-angular-core/ES5/IgPoint";
import { IgxNumericAngleAxisComponent } from "./igx-numeric-angle-axis-component";
import { IgxNumericRadiusAxisComponent } from "./igx-numeric-radius-axis-component";
import { TrendLineType } from "igniteui-angular-core/ES5/TrendLineType";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { PolarBase } from "./PolarBase";
/**
 * Represents the base class from which all IgxDataChartComponent polar series are derived.
*/
export declare const IgxPolarBaseComponent_PROVIDERS: ({
    provide: typeof IgxMarkerSeriesComponent;
    useExisting: Type<any>;
} | {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
})[];
export declare abstract class IgxPolarBaseComponent extends IgxMarkerSeriesComponent {
    /**
                                 * @hidden
                                 */
    readonly i: PolarBase;
    constructor();
    /**
     * Checks if this series is a polar series
    */
    readonly isPolar: boolean;
    /**
     * Gets or sets the path to use to find the angle values for the series.
    */
    angleMemberPath: string;
    /**
     * Gets or sets the path to use to get the radius values for the series.
    */
    radiusMemberPath: string;
    /**
     * Gets the effective angle axis for the current series object.
    */
    angleAxis: IgxNumericAngleAxisComponent;
    /**
     * Gets the effective radius axis for the current series object.
    */
    radiusAxis: IgxNumericRadiusAxisComponent;
    /**
     * Gets or sets whether Cartesian Interpolation should be used rather than Archimedian
     * spiral based interpolation.
    */
    useCartesianInterpolation: boolean;
    /**
     * Gets or sets the maximum number of markers displayed by the current series.
     * If more than the specified number of markers are visible, the polar series will automatically
     * choose a representative set.
    */
    maximumMarkers: number;
    /**
     * Gets or sets the trend type for the current series object.
    */
    trendLineType: TrendLineType;
    /**
     * Gets or sets the brush that specifies how the current series
     * object's trend line is drawn.
    */
    trendLineBrush: string;
    /**
     * Gets the effective TrendLineBrush for this series.
    */
    actualTrendLineBrush: string;
    /**
     * Gets or sets the thickness of the current series object's trend line.
    */
    trendLineThickness: number;
    /**
     * Gets or sets the moving average period for the current series object.
    */
    trendLinePeriod: number;
    /**
     * Sets or Gets the Trendline Z index.
    */
    trendLineZIndex: number;
    /**
     * Gets or sets whether to clip the series to the bounds.
     * Setting this to true can effect performance.
    */
    clipSeriesToBounds: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
     * Scrolls the requested item into view, if possible.
    
    * @param item  * The item to scroll into view.
    */
    scrollIntoView(item: any): boolean;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world: IgPoint): any;
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    */
    getItemIndex(world: IgPoint): number;
    getItemValue(item: any, memberPathName: string): any;
    /**
     * Determine if object can be used as RadiusAxis
    
    * @param axis  * The object to check
    */
    canUseAsRadiusAxis(axis: any): boolean;
    /**
     * Determine if object can be used as AngleAxis
    
    * @param axis  * The object to check
    */
    canUseAsAngleAxis(axis: any): boolean;
}
