import { Type, EventEmitter } from '@angular/core';
import { IgxNumericXAxisComponent } from "./igx-numeric-x-axis-component";
import { IgxNumericYAxisComponent } from "./igx-numeric-y-axis-component";
import { StyleShapeEventArgs } from "./igx-style-shape-event-args";
import { IgxSeriesComponent } from "./igx-series-component";
import { ShapeSeriesBase } from "./ShapeSeriesBase";
/**
 * Series class for rendering polygons.
*/
export declare const IgxShapeSeriesBaseComponent_PROVIDERS: {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
}[];
export declare abstract class IgxShapeSeriesBaseComponent extends IgxSeriesComponent {
    /**
                                 * @hidden
                                 */
    readonly i: ShapeSeriesBase;
    constructor();
    /**
     * The name of the property on ItemsSource items which, for each shape, contains a list of points to be converted to a polygon.
     * To be consistent with the Shapefile technical description, it is expected that each list of points is defined as an IEnumerable of IEnumerable of Point, or in other words, a list of lists of points.
    */
    shapeMemberPath: string;
    /**
     * Gets or sets the effective x-axis for the current ScatterBase object.
    */
    xAxis: IgxNumericXAxisComponent;
    /**
     * Gets or sets the effective y-axis for the current ScatterBase object.
    */
    yAxis: IgxNumericYAxisComponent;
    /**
     * The resolution at which to filter out shapes in the series.  For example, if the ShapeFilterResolution is set to 3, then elements with a bounding rectangle smaller than 3 X 3 pixels will be filtered out.
     * In the case of ScatterPolylineSeries, the resolution is compared to either dimension, rather than both.  In other words, a polyline will not be filtered if its height or its width exceeds the value of this property.  Whereas with a ShapeSeries, both the height and the width must exceed the value of this property.
    */
    shapeFilterResolution: number;
    /**
     * Gets whether or not this series is a shape series
    */
    readonly isShape: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    getItemValue(item: any, memberPathName: string): any;
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    canUseAsYAxis(axis: any): boolean;
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    canUseAsXAxis(axis: any): boolean;
    private _styleShape;
    /**
     * Raised when tile's image URI should be provided
    */
    readonly styleShape: EventEmitter<{
        sender: any;
        args: StyleShapeEventArgs;
    }>;
}
